@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-file-helpers.c 8030 2008-03-04 20:21:38Z wbolster $
+ *  $Id$
  */
 
 #include "config.h"
@@ -43,7 +43,7 @@
 #include <libgnome/gnome-desktop-item.h>
 
 #include <gdk/gdk.h>
-#include <gtk/gtkrecentmanager.h>
+#include <gtk/gtk.h>
 
 #include <string.h>
 #include <stdlib.h>
