@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-link.c,v 1.11 2006/10/01 12:15:56 chpe Exp $
+ *  $Id$
  */
 
 #include "config.h"
@@ -34,7 +34,7 @@ enum
 	LAST_SIGNAL
 };
 
-static guint signals[LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL];
 
 static void
 ephy_link_base_init (gpointer g_class)
@@ -48,12 +48,12 @@ ephy_link_base_init (gpointer g_class)
 			 EPHY_TYPE_LINK,
 			 G_SIGNAL_RUN_LAST,
 			 G_STRUCT_OFFSET (EphyLinkIface, open_link),
-			 ephy_signal_accumulator_object, ephy_tab_get_type,
+			 ephy_signal_accumulator_object, ephy_embed_get_type,
 			 ephy_marshal_OBJECT__STRING_OBJECT_FLAGS,
-			 EPHY_TYPE_TAB,
+			 GTK_TYPE_WIDGET /* Can't use an interface type here */,
 			 3,
 			 G_TYPE_STRING,
-			 EPHY_TYPE_TAB,
+			 GTK_TYPE_WIDGET /* Can't use an interface type here */,
 			 EPHY_TYPE_LINK_FLAGS);
 
 		initialised = TRUE;
@@ -82,21 +82,21 @@ ephy_link_get_type (void)
 	return type;
 }
 
-EphyTab	*
+EphyEmbed *
 ephy_link_open (EphyLink *link,
 		const char *address,
-		EphyTab *tab,
+		EphyEmbed *embed,
 		EphyLinkFlags flags)
 {
-	EphyTab *new_tab = NULL;
+	EphyEmbed *new_embed = NULL;
 
-	LOG ("ephy_link_open address \"%s\" parent-tab %p flags %u", address, tab, flags);
+	LOG ("ephy_link_open address \"%s\" parent-embed %p flags %u", address, embed, flags);
 
 	g_signal_emit (link, signals[OPEN_LINK], 0,
-		       address, tab, flags,
-		       &new_tab);
+		       address, embed, flags,
+		       &new_embed);
 
-	return new_tab;
+	return new_embed;
 }
 
 EphyLinkFlags
@@ -114,7 +114,7 @@ ephy_link_flags_from_current_event (void)
 		{
 			flags = EPHY_LINK_NEW_WINDOW;
 		}
-		else if (state == 0)
+		else if (state == 0 || state == GDK_CONTROL_MASK)
 		{
 			flags = EPHY_LINK_NEW_TAB;
 		}
