@@ -40,9 +40,7 @@
 #include <glib/gi18n.h>
 
 #include <gdk/gdkx.h>
-#include <gtk/gtkaboutdialog.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtk.h>
 
 #include <libgnome/gnome-program.h>
 #include <libgnomeui/gnome-ui-init.h>
@@ -52,6 +50,10 @@
 #include <errno.h>
 #include <string.h>
 
+#ifdef HAVE_LIBNOTIFY
+#include <libnotify/notify.h>
+#endif
+
 static GQuark startup_error_quark = 0;
 #define STARTUP_ERROR_QUARK	(startup_error_quark)
 
@@ -238,8 +240,8 @@ unref_proxy_reply_cb (DBusGProxy *proxy,
 {
 	if (error != NULL)
 	{
-		g_warning ("An error occured while calling remote method: %s", error->message);
-		g_error_free (error);/* FIXME??? */
+		g_warning ("An error occurred while calling remote method: %s", error->message);
+		g_error_free (error);
 	}
 
 	g_object_unref (proxy);
@@ -739,9 +741,18 @@ main (int argc,
 	g_object_weak_ref (G_OBJECT (ephy_shell), shell_weak_notify, NULL);
 	ephy_object_idle_unref (ephy_shell);
 
+#ifdef HAVE_LIBNOTIFY	
+	/* Init notifications for the download manager */
+	notify_init (PACKAGE);
+#endif
+
 	gtk_main ();
 
 	/* Shutdown */
+#ifdef HAVE_LIBNOTIFY	
+	if (notify_is_initted ())
+		notify_uninit ();
+#endif
 	eel_gconf_monitor_remove ("/apps/epiphany/general");
 	gnome_accelerators_sync ();
 	ephy_state_save ();
