@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-statusbar.c 7127 2007-07-10 11:56:30Z chpe $
+ *  $Id$
  */
 
 #include "config.h"
@@ -27,13 +27,7 @@
 
 #include <string.h>
 #include <glib/gi18n.h>
-#include <gtk/gtklabel.h>	
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkprogressbar.h>
-#include <gtk/gtkeventbox.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkvseparator.h>
+#include <gtk/gtk.h>	
 
 static void ephy_statusbar_class_init	(EphyStatusbarClass *klass);
 static void ephy_statusbar_init		(EphyStatusbar *t);
@@ -60,43 +54,14 @@ enum
 };
 
 static guint signals[LAST_SIGNAL];
-static GObjectClass *parent_class;
 
-GType
-ephy_statusbar_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		const GTypeInfo our_info =
-		{
-			sizeof (EphyStatusbarClass),
-			NULL, /* base_init */
-			NULL, /* base_finalize */
-			(GClassInitFunc) ephy_statusbar_class_init,
-			NULL,
-			NULL, /* class_data */
-			sizeof (EphyStatusbar),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) ephy_statusbar_init
-		};
-
-		type = g_type_register_static (GTK_TYPE_STATUSBAR,
-					       "EphyStatusbar",
-					       &our_info, 0);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE (EphyStatusbar, ephy_statusbar, GTK_TYPE_STATUSBAR)
 
 static void
 ephy_statusbar_class_init (EphyStatusbarClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	parent_class = g_type_class_peek_parent (klass);
-
 	signals[LOCK_CLICKED] =
 		g_signal_new
 			("lock-clicked",
